@@ -66,6 +66,7 @@ import (
 	"golang.org/x/tools/gopls/internal/protocol"
 	"golang.org/x/tools/gopls/internal/util/bug"
 	"golang.org/x/tools/gopls/internal/util/safetoken"
+	"golang.org/x/tools/internal/aliases"
 	"golang.org/x/tools/internal/diff"
 	"golang.org/x/tools/internal/event"
 	"golang.org/x/tools/internal/typesinternal"
@@ -126,7 +127,7 @@ func PrepareRename(ctx context.Context, snapshot *cache.Snapshot, f file.Handle,
 	if err != nil {
 		return nil, nil, err
 	}
-	targets, node, err := objectsAt(pkg.GetTypesInfo(), pgf.File, pos)
+	targets, node, err := objectsAt(pkg.TypesInfo(), pgf.File, pos)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -322,7 +323,7 @@ func renameOrdinary(ctx context.Context, snapshot *cache.Snapshot, f file.Handle
 		if err != nil {
 			return nil, err
 		}
-		objects, _, err := objectsAt(pkg.GetTypesInfo(), pgf.File, pos)
+		objects, _, err := objectsAt(pkg.TypesInfo(), pgf.File, pos)
 		if err != nil {
 			return nil, err
 		}
@@ -352,7 +353,7 @@ func renameOrdinary(ctx context.Context, snapshot *cache.Snapshot, f file.Handle
 		// of the type parameters, unlike methods).
 		switch obj.(type) { // avoid "obj :=" since cases reassign the var
 		case *types.TypeName:
-			if _, ok := obj.Type().(*types.TypeParam); ok {
+			if _, ok := aliases.Unalias(obj.Type()).(*types.TypeParam); ok {
 				// As with capitalized function parameters below, type parameters are
 				// local.
 				goto skipObjectPath
@@ -587,7 +588,7 @@ func renameExported(pkgs []*cache.Package, declPkgPath PackagePath, declObjPath
 			// TODO(adonovan): methods requires dynamic
 			// programming of the product targets x
 			// packages as any package might add a new
-			// target (from a foward dep) as a
+			// target (from a forward dep) as a
 			// consequence, and any target might imply a
 			// new set of rdeps. See golang/go#58461.
 		}
@@ -900,10 +901,10 @@ func renameImports(ctx context.Context, snapshot *cache.Snapshot, mp *metadata.P
 					continue // not the import we're looking for
 				}
 
-				pkgname := pkg.GetTypesInfo().Implicits[imp].(*types.PkgName)
+				pkgname := pkg.TypesInfo().Implicits[imp].(*types.PkgName)
 
-				pkgScope := pkg.GetTypes().Scope()
-				fileScope := pkg.GetTypesInfo().Scopes[f.File]
+				pkgScope := pkg.Types().Scope()
+				fileScope := pkg.TypesInfo().Scopes[f.File]
 
 				localName := string(newName)
 				try := 0
@@ -1025,7 +1026,7 @@ func (r *renamer) update() (map[protocol.DocumentURI][]diff.Edit, error) {
 		isDef bool
 	}
 	var items []item
-	info := r.pkg.GetTypesInfo()
+	info := r.pkg.TypesInfo()
 	for id, obj := range info.Uses {
 		if shouldUpdate(obj) {
 			items = append(items, item{id, obj, false})
@@ -1163,7 +1164,7 @@ func (r *renamer) updateCommentDocLinks() (map[protocol.DocumentURI][]diff.Edit,
 		// Doc links can reference only exported package-level objects
 		// and methods of exported package-level named types.
 		if !isPackageLevel(obj) {
-			_, isFunc := obj.(*types.Func)
+			obj, isFunc := obj.(*types.Func)
 			if !isFunc {
 				continue
 			}
@@ -1188,12 +1189,12 @@ func (r *renamer) updateCommentDocLinks() (map[protocol.DocumentURI][]diff.Edit,
 
 		// Qualify objects from other packages.
 		pkgName := ""
-		if r.pkg.GetTypes() != obj.Pkg() {
+		if r.pkg.Types() != obj.Pkg() {
 			pkgName = obj.Pkg().Name()
 		}
 		_, isTypeName := obj.(*types.TypeName)
 		docRenamers = append(docRenamers, &docLinkRenamer{
-			isDep:       r.pkg.GetTypes() != obj.Pkg(),
+			isDep:       r.pkg.Types() != obj.Pkg(),
 			isPkgOrType: isTypeName,
 			packagePath: obj.Pkg().Path(),
 			packageName: pkgName,
